<?php

return [
    // 支付类型
    'payment_types' => [
        'wechat' => '위챗 페이',
        'alipay' => '알리페이',
        'unionpay' => '유니온페이',
        'douyin' => '도우인 페이',
        'jsbank' => 'JS 뱅크',
        'alipay_global' => '알리페이 글로벌',
        'paypal' => '페이팔',
        'stripe' => '스트라이프',
        'google_pay' => '구글 페이',
        'apple_pay' => '애플 페이',
    ],

    // 支付状态
    'payment_statuses' => [
        'pending' => '대기 중',
        'success' => '성공',
        'failed' => '실패',
        'refunded' => '환불 완료',
        'closed' => '닫힘',
    ],

    // 支付操作
    'payment_actions' => [
        'pay' => '결제',
        'query' => '조회',
        'refund' => '환불',
        'close' => '닫기',
        'callback' => '콜백',
    ],

    // 错误信息
    'errors' => [
        'invalid_payment_type' => '유효하지 않은 결제 방법입니다',
        'payment_failed' => '결제에 실패했습니다',
        'refund_failed' => '환불에 실패했습니다',
        'order_not_found' => '주문을 찾을 수 없습니다',
        'invalid_signature' => '서명이 유효하지 않습니다',
        'ip_not_allowed' => 'IP 주소가 허용되지 않습니다',
        'timeout' => '시간 초과되었습니다',
        'config_error' => '설정 오류입니다',
    ],

    // 成功信息
    'success' => [
        'payment_success' => '결제가 성공했습니다',
        'refund_success' => '환불이 성공했습니다',
        'query_success' => '조회가 성공했습니다',
        'close_success' => '주문을 닫았습니다',
        'callback_success' => '콜백이 성공했습니다',
    ],

    // 提示信息
    'messages' => [
        'please_pay' => '결제해 주세요',
        'payment_processing' => '결제 처리 중입니다',
        'redirecting' => '리디렉션 중입니다',
        'please_wait' => '기다려 주세요',
        'operation_success' => '작업이 성공했습니다',
        'operation_failed' => '작업에 실패했습니다',
    ],

    // 统计信息
    'statistics' => [
        'total_payments' => '총 결제 수',
        'total_amount' => '총 금액',
        'success_rate' => '성공률',
        'average_amount' => '평균 금액',
        'payment_by_method' => '결제 방법별',
        'payment_by_date' => '날짜별 결제',
        'refund_rate' => '환불률',
        'top_payments' => '상위 결제',
    ],

    // 货币符号
    'currencies' => [
        'CNY' => '¥',
        'USD' => '$',
        'EUR' => '€',
        'JPY' => '¥',
        'KRW' => '₩',
        'GBP' => '£',
        'HKD' => 'HK$',
        'TWD' => 'NT$',
        'AUD' => 'A$',
        'CAD' => 'C$',
    ],
];
