<?php

namespace Kylin\Payment\Http\Middleware;

use Illuminate\Support\ServiceProvider;

/**
 * 中间件服务提供者
 */
class MiddlewareServiceProvider extends ServiceProvider
{
    /**
     * 注册服务
     */
    public function register(): void
    {
        // 注册中间件
        $this->app['router']->aliasMiddleware('kylin.payment.callback', PaymentCallbackMiddleware::class);
    }

    /**
     * 引导服务
     */
    public function boot(): void
    {
        //
    }
}
