<?php

use Illuminate\Support\Facades\Route;
use Kylin\Payment\Http\Controllers\DashboardController;

// 支付仪表盘路由
Route::prefix('kylin-payment')->name('kylin-payment.')->group(function () {
    // 仪表盘首页
    Route::get('dashboard', [DashboardController::class, 'index'])->name('dashboard.index');
    
    // 获取统计数据（AJAX）
    Route::get('dashboard/stats', [DashboardController::class, 'getStats'])->name('dashboard.stats');
    
    // 支付记录列表
    Route::get('dashboard/payments', [DashboardController::class, 'payments'])->name('dashboard.payments');
    
    // 回调日志列表
    Route::get('dashboard/callbacks', [DashboardController::class, 'callbacks'])->name('dashboard.callbacks');
    
    // 回调日志详情
    Route::get('dashboard/callback/detail', [DashboardController::class, 'callbackDetail'])->name('dashboard.callback.detail');
});
