<?php

return [
    // Payment types
    'payment_types' => [
        'wechat' => 'WeChat Pay',
        'alipay' => 'Alipay',
        'unionpay' => 'UnionPay',
        'douyin' => 'Douyin Pay',
        'jsbank' => 'JS Bank',
        'alipay_global' => 'Alipay Global',
        'paypal' => 'PayPal',
        'stripe' => 'Stripe',
        'google_pay' => 'Google Pay',
        'apple_pay' => 'Apple Pay',
        'order_no' => 'Order No',
        'gateway' => 'Gateway',
        'gateway_trade_no' => 'Gateway Trade No',
    ],

    // Payment statuses
    'payment_statuses' => [
        'pending' => 'Pending',
        'success' => 'Success',
        'failed' => 'Failed',
        'refunded' => 'Refunded',
        'closed' => 'Closed',
        'status' => 'Status',
    ],

    // Payment actions
    'payment_actions' => [
        'pay' => 'Pay',
        'query' => 'Query',
        'refund' => 'Refund',
        'close' => 'Close',
        'callback' => 'Callback',
    ],

    // Error messages
    'errors' => [
        'payment_failed' => 'Payment failed',
        'refund_failed' => 'Refund failed',
        'close_failed' => 'Close order failed',
        'query_failed' => 'Query order failed',
        'callback_failed' => 'Process callback failed',
        'invalid_payment_type' => 'Unsupported payment type',
        'invalid_payment_config' => 'Invalid payment configuration',
        'invalid_order_no' => 'Invalid order number',
        'payment_record_not_found' => 'Payment record not found',
        'callback_log_not_found' => 'Callback log not found',
        'order_not_found' => 'Order not found',
        'operation_failed' => 'Operation failed',
    ],

    // Success messages
    'successes' => [
        'payment_success' => 'Payment successful',
        'refund_success' => 'Refund successful',
        'close_success' => 'Close order successful',
        'query_success' => 'Query order successful',
        'callback_success' => 'Process callback successful',
        'payment_record_created' => 'Payment record created successfully',
        'callback_log_created' => 'Callback log created successfully',
    ],

    // Prompt messages
    'messages' => [
        'please_pay' => 'Please complete payment',
        'payment_expired' => 'Payment expired',
        'payment_processing' => 'Payment processing',
        'refund_processing' => 'Refund processing',
        'close_confirm' => 'Are you sure to close this order?',
        'refund_confirm' => 'Are you sure to refund?',
        'all' => 'All',
        'search' => 'Search',
        'reset' => 'Reset',
        'view' => 'View',
        'close' => 'Close',
        'loading' => 'Loading',
        'actions' => 'Actions',
    ],

    // Statistics
    'statistics' => [
        'total_count' => 'Total Orders',
        'success_count' => 'Success Orders',
        'failed_count' => 'Failed Orders',
        'pending_count' => 'Pending Orders',
        'refunded_count' => 'Refunded Orders',
        'closed_count' => 'Closed Orders',
        'total_amount' => 'Total Amount',
        'success_amount' => 'Success Amount',
        'refunded_amount' => 'Refunded Amount',
        'success_rate' => 'Success Rate',
        'refund_rate' => 'Refund Rate',
        'payment_trend' => 'Payment Trend',
        'refund_statistics' => 'Refund Statistics',
        'success_rate_ranking' => 'Success Rate Ranking',
        'payment_records' => 'Payment Records',
        'callback_logs' => 'Callback Logs',
        'dashboard' => 'Dashboard',
        'date' => 'Date',
        'amount' => 'Amount',
        'client_ip' => 'Client IP',
        'created_at' => 'Created At',
        'updated_at' => 'Updated At',
        'method' => 'Method',
        'url' => 'URL',
        'ip' => 'IP',
        'headers' => 'Headers',
        'body' => 'Body',
        'response' => 'Response',
        'callback_detail' => 'Callback Detail',
        'payment_by_status' => 'Payment by Status',
        'payment_by_method' => 'Payment by Method',
        'payment_by_date' => 'Payment by Date',
        'total_payments' => 'Total Payments',
    ],
];

