<?php

use Illuminate\Support\Facades\Route;
use Kylin\Payment\Http\Controllers\ReportController;

// 支付报表路由
Route::prefix('kylin-payment')->name('kylin-payment.')->group(function () {
    // 报表首页
    Route::get('report', [ReportController::class, 'index'])->name('report.index');
    
    // 生成报表数据（AJAX）
    Route::get('report/generate', [ReportController::class, 'generate'])->name('report.generate');
    
    // 导出Excel报表
    Route::get('report/export-excel', [ReportController::class, 'exportExcel'])->name('report.export-excel');
    
    // 导出PDF报表
    Route::get('report/export-pdf', [ReportController::class, 'exportPdf'])->name('report.export-pdf');
    
    // 导出CSV报表
    Route::get('report/export-csv', [ReportController::class, 'exportCsv'])->name('report.export-csv');
});
