<?php

return [
    // 支付类型
    'payment_types' => [
        'wechat' => 'WeChat Pay',
        'alipay' => 'Alipay',
        'unionpay' => 'UnionPay',
        'douyin' => 'Douyin Pay',
        'jsbank' => 'JS Bank',
        'alipay_global' => 'Alipay Global',
        'paypal' => 'PayPal',
        'stripe' => 'Stripe',
        'google_pay' => 'Google Pay',
        'apple_pay' => 'Apple Pay',
    ],

    // 支付状态
    'payment_statuses' => [
        'pending' => 'En attente',
        'success' => 'Succès',
        'failed' => 'Échoué',
        'refunded' => 'Remboursé',
        'closed' => 'Fermé',
    ],

    // 支付操作
    'payment_actions' => [
        'pay' => 'Payer',
        'query' => 'Rechercher',
        'refund' => 'Rembourser',
        'close' => 'Fermer',
        'callback' => 'Callback',
    ],

    // 错误信息
    'errors' => [
        'invalid_payment_type' => 'Type de paiement invalide',
        'payment_failed' => 'Échec du paiement',
        'refund_failed' => 'Échec du remboursement',
        'order_not_found' => 'Commande non trouvée',
        'invalid_signature' => 'Signature invalide',
        'ip_not_allowed' => 'Adresse IP non autorisée',
        'timeout' => 'Délai dépassé',
        'config_error' => 'Erreur de configuration',
    ],

    // 成功信息
    'success' => [
        'payment_success' => 'Paiement réussi',
        'refund_success' => 'Remboursement réussi',
        'query_success' => 'Recherche réussie',
        'close_success' => 'Commande fermée',
        'callback_success' => 'Callback réussi',
    ],

    // 提示信息
    'messages' => [
        'please_pay' => 'Veuillez payer',
        'payment_processing' => 'Traitement du paiement',
        'redirecting' => 'Redirection...',
        'please_wait' => 'Veuillez patienter',
        'operation_success' => 'Opération réussie',
        'operation_failed' => 'Échec de lopération',
    ],

    // 统计信息
    'statistics' => [
        'total_payments' => 'Total des paiements',
        'total_amount' => 'Montant total',
        'success_rate' => 'Taux de réussite',
        'average_amount' => 'Montant moyen',
        'payment_by_method' => 'Paiement par méthode',
        'payment_by_date' => 'Paiement par date',
        'refund_rate' => 'Taux de remboursement',
        'top_payments' => 'Top paiements',
    ],

    // 货币符号
    'currencies' => [
        'CNY' => '¥',
        'USD' => '$',
        'EUR' => '€',
        'JPY' => '¥',
        'KRW' => '₩',
        'GBP' => '£',
        'HKD' => 'HK$',
        'TWD' => 'NT$',
        'AUD' => 'A$',
        'CAD' => 'C$',
    ],
];
